@@ -2,11 +2,11 @@ from io import BufferedIOBase, RawIOBase
 from drb.core.node import DrbNode
 from drb.nodes.abstract_node import AbstractNode
 from drb.core.path import ParsedPath
-from drb.exceptions.core import DrbNotImplementationException, DrbException
-from typing import Dict, List, Optional, Any, Tuple, Union
-from typing.io import IO
+from drb.exceptions.core import DrbNotImplementationException
+from deprecated import deprecated
+from typing import Dict, List, Optional, Any, Tuple, Union, IO
 import json
-import os
+from pathlib import Path
 
 
 class JsonNode(AbstractNode):
@@ -20,64 +20,39 @@ class JsonNode(AbstractNode):
             parent (DrbNode): The parent of this node (default: None).
             data : The json data (default: None).
     """
-    supported_impl = [dict, str, list]
 
     def __init__(self, path: Union[str, Dict, list],
                  parent: DrbNode = None, data=None):
         super().__init__()
         if data is not None:
             self._data = data
-            self._name = os.path.basename(path)
+            self.name = Path(path).name
             self._path = ParsedPath(path)
         elif isinstance(path, dict) or isinstance(path, list):
             self._data = path
-            self._name = None
+            self.name = None
             self._path = ParsedPath('/')
         elif isinstance(parent, JsonNode):
-            self._name = os.path.basename(path)
+            self.name = Path(path).name
             self._path = ParsedPath(path)
             self._data = None
         else:
             with open(path) as jsonFile:
                 self._data = json.load(jsonFile)
                 jsonFile.close()
-                self._name = os.path.basename(path)
+                self.name = Path(path).name
                 self._path = ParsedPath(path)
 
-        self._parent = parent
+        self._available_impl += [dict, str, list]
+        self.parent = parent
         self._children = None
-
-    @property
-    def name(self) -> str:
-        return self._name
-
-    @property
-    def namespace_uri(self) -> Optional[str]:
-        return None
-
-    @property
-    def value(self) -> Optional[Any]:
-        return self._data
-
-    @property
-    def attributes(self) -> Dict[Tuple[str, str], Any]:
-        return {}
-
-    def get_attribute(self, name: str, namespace_uri: str = None) -> Any:
-        raise DrbException(f'No attribute ({name}:{namespace_uri}) found!')
-
-    @property
-    def parent(self) -> Optional[DrbNode]:
-        return self._parent
+        self.value = self._data
 
     @property
     def path(self) -> ParsedPath:
         return self._path
 
-    def has_impl(self, impl: type) -> bool:
-        return impl in JsonNode.supported_impl
-
-    def get_impl(self, impl: type) -> Any:
+    def get_impl(self, impl: type, **kwargs) -> Any:
         if self.has_impl(impl):
             if impl == dict:
                 return json.load(self._data)
@@ -85,6 +60,8 @@ class JsonNode(AbstractNode):
                 if isinstance(self._data, list):
                     return self._data
                 return [self._data]
+            elif impl == BufferedIOBase:
+                return json.dumps(self._data).encode('utf-8')
             else:
                 return json.dumps(self._data)
 
@@ -108,6 +85,8 @@ class JsonNode(AbstractNode):
         return isinstance(self._data, dict) or isinstance(self._data, list)
 
     @property
+    @deprecated(version='1.2.0',
+                reason='Only bracket browse should be use')
     def children(self) -> List[DrbNode]:
         if self._children is None:
             self._children = []
@@ -123,23 +102,31 @@ class JsonNode(AbstractNode):
                         if isinstance(self._data[e], list):
                             for x in self._data[e]:
                                 self._children.append(
-                                    JsonNode(path=os.path.join(
-                                        self.path.path, e),
+                                    JsonNode(
+                                        path=Path(self.path.path).joinpath(e)
+                                        .as_posix(),
                                         parent=self,
                                         data=x)
                                 )
                         else:
                             self._children.append(
-                                JsonNode(path=os.path.join(self.path.path, e),
-                                         parent=self,
-                                         data=self._data[e])
+                                JsonNode(
+                                    path=Path(self.path.path).joinpath(e)
+                                    .as_posix(),
+                                    parent=self,
+                                    data=self._data[e])
                             )
             else:
                 self._children = []
         return self._children
 
-    def close(self) -> None:
-        pass
+    def __setitem__(self, key, value):
+        raise NotImplementedError(
+            'Not supported in this version of drb-driver-json')
+
+    def __delitem__(self, key):
+        raise NotImplementedError(
+            'Not supported in this version of drb-driver-json')
 
 
 class JsonBaseNode(AbstractNode):
@@ -165,6 +152,12 @@ class JsonBaseNode(AbstractNode):
     def name(self) -> str:
         return self.base_node.name
 
+    def impl_capabilities(self) -> List[type]:
+        return self.base_node._available_impl.copy()
+
+    def attribute_names(self):
+        return self.base_node.attribute_names()
+
     @property
     def namespace_uri(self) -> Optional[str]:
         return self.base_node.namespace_uri
@@ -182,10 +175,13 @@ class JsonBaseNode(AbstractNode):
         return self.base_node.parent
 
     @property
+    @deprecated(version='1.2.0',
+                reason='Usage of the @ operator is recommended')
     def attributes(self) -> Dict[Tuple[str, str], Any]:
         return self.base_node.attributes
 
     @property
+    @deprecated(version='1.2.0', reason='Only bracket browse should be use')
     def children(self) -> List[DrbNode]:
         return [self.json_node]
 
@@ -196,6 +192,8 @@ class JsonBaseNode(AbstractNode):
             return False
         return True
 
+    @deprecated(version='1.2.0',
+                reason='Usage of the @ operator is recommended')
     def get_attribute(self, name: str) -> Any:
         return self.base_node.get_attribute(name)
 
@@ -205,6 +203,14 @@ class JsonBaseNode(AbstractNode):
     def get_impl(self, impl: type, **kwargs) -> Any:
         return self.base_node.get_impl(impl)
 
+    def __setitem__(self, key, value):
+        raise NotImplementedError(
+            'Not supported in this version of drb-driver-json')
+
+    def __delitem__(self, key):
+        raise NotImplementedError(
+            'Not supported in this version of drb-driver-json')
+
     def close(self) -> None:
         if self.source:
             self.source.close()
